@@ -59,6 +59,7 @@ char *endptr;
 static int hardFlag=0;
 static int postFlag=0;
 
+
 static void split_input(void)
 {
   /* r points to the last non-space character */
@@ -246,6 +247,7 @@ void cmd_hash(void)
 /* Give a possible move for the player to play */
 void cmd_hint(void)
 {
+  /* An answer is received only if book on - TODO change this in adapter */
   SetDataToEngine( token[0] );
   /* TODO if no hint, inform on stdout */
 }
@@ -327,15 +329,16 @@ void cmd_load(void)
 
 void cmd_manual(void)
 {
-  SetDataToEngine( "force" );
   SET (flags, MANUAL);
+  ExpectAnswerFromEngine( false );
+  SetDataToEngine( "force" );
 }
 
 void cmd_memory(void)
 {
   if (token[1][0] == 0) {
-    SetDataToEngine( "memory" );
     ExpectAnswerFromEngine( true );
+    SetDataToEngine( "memory" );
   } else {
     unsigned int memory;
     if ( sscanf( token[1], "%d", &memory ) == 1 ) {
@@ -343,6 +346,7 @@ void cmd_memory(void)
       sprintf( data, "memory %d\nmemory", memory );
       SetDataToEngine( data );
     }
+/* TODO Handle error */
   }
 }
 
@@ -401,6 +405,7 @@ void cmd_nopost(void)
 {
   CLEAR (flags, POST);
   postFlag = 0;
+  ExpectAnswerFromEngine( false );
   SetDataToEngine( token[0] );
 }
 
@@ -499,8 +504,10 @@ void cmd_pgnreplay(void)
 
 void cmd_next(void)
 {
-  if (!pgnloaded)
+  if (!pgnloaded) {
+    printf(_("Error: PGN file not loaded!\n"));
     return;
+  }
 
   if ((GameCnt+1) <= pgncnt) {
     ChangeColor( true );
@@ -518,8 +525,10 @@ void cmd_next(void)
 
 void cmd_previous(void)
 {
-  if (!pgnloaded)
+  if (!pgnloaded) {
+    printf(_("Error: PGN file not loaded!\n"));
     return;
+  }
 
   if (GameCnt >= 0) {
     ChangeColor( true );
@@ -538,8 +547,10 @@ void cmd_previous(void)
 
 void cmd_last(void)
 {
-  if (!pgnloaded)
+  if (!pgnloaded) {
+    printf(_("Error: PGN file not loaded!\n"));
     return;
+  }
 
   while (GameCnt+1 <= pgncnt) {
     ChangeColor( true );
@@ -554,8 +565,10 @@ void cmd_last(void)
 
 void cmd_first(void)
 {
-  if (!pgnloaded)
+  if (!pgnloaded) {
+    printf(_("Error: PGN file not loaded!\n"));
     return;
+  }
 
   while (GameCnt >= 0) {
     if (GameCnt >= 0) {
@@ -600,6 +613,7 @@ void cmd_nographic(void)
 
 void cmd_ping(void)
 {
+  /* TODO cf. 5.08 */
   SetDataToEngine( token[0] );
   /* If ping is received when we are on move, we are supposed to
      reply only after moving.  In this version of GNU Chess, we
@@ -611,11 +625,15 @@ void cmd_ping(void)
 
 void cmd_post(void)
 {
+  /* TODO State makes no sense */
   SET (flags, POST);
   postFlag = 1;
   if ( hardFlag && postFlag )
     ExpectAnswerFromEngine( true );
-  ExpectAnswerFromEngine( true );
+  if ( flags & XBOARD )
+    ExpectAnswerFromEngine( true );
+  else
+    ExpectAnswerFromEngine( false );
   SetDataToEngine( token[0] );
 }
 
@@ -673,6 +691,7 @@ void cmd_remove(void)
 
 void cmd_result(void)
 {
+  /* TODO Do not send to engine */
   SetDataToEngine( token[0] );
   if (ofp != stdout) {
     fprintf(ofp, "result: %s\n",token[1]);
@@ -703,7 +722,10 @@ void cmd_setboard(void)
   SetDataToEngine(data);
 }
 
-void cmd_solve(void) { Solve (token[1]); }
+void cmd_solve(void)
+{
+  Solve (token[1]);
+}
 
 /* Set total time for move to be N seconds is "st N" */
 void cmd_st(void)
@@ -724,10 +746,9 @@ void cmd_switch(void)
 
 void cmd_time(void)
 {
+  /* TODO send what? */
   SetDataToEngine( token[0] );
-  printf( _("Old TimeLimit = %g\n"), TimeLimit[1^board.side] );
   TimeLimit[1^board.side] = atoi(token[1]) / 100.0f ;
-  printf( _("New TimeLimit = %g\n"), TimeLimit[1^board.side] );
 }
 
 void cmd_undo(void)
@@ -803,6 +824,7 @@ Report bugs to <bug-gnu-chess@gnu.org>.\n\
 /* Play variant, we instruct interface in protover we play normal */
 void cmd_variant(void) {}
 
+/* TODO Not in 5.08 */
 void cmd_usermove(void)
 {
   /* TODO: Remove the first SetDataToEngine */
@@ -854,6 +876,16 @@ void cmd_version(void)
      printf ("Chess\n");
 }
 
+void cmd_coords(void) {
+    printf(_("Coordinate display enabled.\n"));
+    coords = 1;
+}
+
+void cmd_nocoords(void) {
+    printf(_("Coordinate display disabled.\n"));
+    coords = 0;
+}
+
 void cmd_white(void)
 {
  /*
@@ -886,6 +918,7 @@ void cmd_show (void)
  *
  ************************************************************************/
 {
+   /* TODO Remove gettext support */
    if (tokeneq (token[1], "board"))
       ShowBoard ();
    else if (tokeneq (token[1], "rating"))
@@ -1091,6 +1124,10 @@ static const char * const helpstr[] = {
    gettext_noop(" Enables display board in graphic mode."),
    "nographic",
    gettext_noop(" Disables graphic mode and display classical view."),
+   "coords",
+   gettext_noop(" Displays the chessboard rank and file in both graphic and classical views."),
+   "nocoords",
+   gettext_noop(" Does not display the chessboard rank nor file in either mode (graphic nor classical)"),
    NULL,
    NULL
 };
@@ -1213,6 +1250,8 @@ const struct methodtable commands[] = {
   { "version", cmd_version },
   { "white", cmd_white },
   { "xboard", cmd_xboard },
+  { "coords", cmd_coords},
+  { "nocoords", cmd_nocoords},
   { NULL, NULL }
 };
 
