@@ -1,6 +1,6 @@
 /* GNU Chess 6 - main.cc - entry point
 
-   Copyright (c) 2001-2016 Free Software Foundation, Inc.
+   Copyright (c) 2001-2017 Free Software Foundation, Inc.
 
    GNU Chess is based on the two research programs
    Cobalt by Chua Kong-Sian and Gazebo by Stuart Cracraft.
@@ -33,6 +33,7 @@
 #include <errno.h>
 #include <unistd.h>
 #include <locale.h>
+#include <signal.h>
 
 #include "frontend/common.h"
 #include "gettext.h"
@@ -89,6 +90,7 @@ float TCTime;
 int phase;
 short bookfirstlast;
 short graphicmodeoutput;
+short coords;
 short pgnloaded = 0;
 int pgncnt = 0;
 
@@ -214,6 +216,12 @@ int Mask315[64] =
 
 extern char userinputbuf[];
 
+void EndProg( int sig __attribute__ ((unused)) )
+{
+    system( "stty sane" );
+    exit(0);
+}
+
 int main (int argc, char *argv[])
 {
   int i;
@@ -383,7 +391,7 @@ Copyright (C) %s Free Software Foundation, Inc.\n\
 License GPLv3+: GNU GPL version 3 or later <http://gnu.org/licenses/gpl.html>\n\
 This is free software: you are free to change and redistribute it.\n\
 There is NO WARRANTY, to the extent permitted by law.\n"),
-             "2016" );
+             "2017" );
   }
 
   /* If a usage statement is required output it here */
@@ -397,6 +405,12 @@ There is NO WARRANTY, to the extent permitted by law.\n"),
   if ( opt_memory != 0 )
     ; /* TODO: to be removed - this is handled by the adapter */
 
+  /* Catch SIGINT to exit. */
+  struct sigaction action;
+  memset( &action, 0, sizeof(struct sigaction) );
+  action.sa_handler = EndProg;
+  sigaction( SIGINT, &action, NULL );
+
   Initialize ();
   InitFrontend();
   if ( ! (flags & UCI ) ) {
@@ -486,8 +500,6 @@ There is NO WARRANTY, to the extent permitted by law.\n"),
       ForwardUserInputToEngine();
       ForwardEngineOutputToUser();
     } else { /* Classical GNU Chess mode */
-      /* Prompt the user, if neither in xboard nor uci mode */
-      ShowPrompt();
       /* Check if there is a new command from the user */
       NextUserCmd();
       /* Show thinking message */
@@ -510,6 +522,7 @@ There is NO WARRANTY, to the extent permitted by law.\n"),
 
   /* Termintate adapter and engine threads and join them */
   TerminateAdapterEngine();
+  TerminateInput();
   
   return (0);
 }
